==> testsuite-3.0.43-beta1.tar.gz: testsuite/modules/phpstan_tests/src/Form/PhpstanTestsFilterForm.php <==
<?php

namespace Drupal\phpstan_tests\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\phpstan_tests\PhpstanTestsResourceService;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class PhpstanTestsFilterForm extends FormBase {
  use BaseTrait;

  /**
   * The array of filters.
   *
   * @var array
   */
  public $filters = [
    'action',
    'area',
    'module',
  ];

  /**
   * The database.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Load the Resource Service.
   *
   * @var \Drupal\phpstan_tests\PhpstanTestsResourceService
   */
  protected $phpstanTestsResourceService;

  /**
   * The time interface.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * PhpUnitTestsForm constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Load messenger service.
   * @param \Drupal\phpstan_tests\PhpstanTestsResourceService $phpstanTestsResourceService
   *   The load resource service.
   * @param \Drupal\Component\Datetime\TimeInterface $timeInterface
   *   The load resource service.
   */
  public function __construct(
    Connection $connection,
    MessengerInterface $messenger,
    PhpstanTestsResourceService $phpstanTestsResourceService,
    TimeInterface $timeInterface
  ) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->phpstanTestsResourceService = $phpstanTestsResourceService;
    $this->timeInterface = $timeInterface;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('messenger'),
      $container->get('phpstan_tests.load_resource.service'),
      $container->get('datetime.time')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'phpstan_tests_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('phpstan_tests_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'phpstan_tests/phpstan_tests.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-tests-filter-form-wrapper',
      ],
    ];

    $action_dropdown = $form_state->hasValue('action') ? $form_state->getValue('action') : '';

    $form['filters']['filters-container']['action-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-test-action-container',
      ],
    ];
    $form['filters']['filters-container']['action-container']['action'] = [
      '#title' => 'Actions',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'filter' => $this->t('Filter'),
        'test' => $this->t('Run Test'),
      ],
      '#default_value' => !empty($session_filters['action']) ? $session_filters['action'] : $action_dropdown,
    ];

    $areaDropdown = $form_state->hasValue('area') ? $form_state->getValue('area') : '';
    $area_dropdown = !empty($session_filters['area']) ? $session_filters['area'] : $areaDropdown;

    $form['filters']['filters-container']['area-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-test-areas-container',
      ],
    ];
    $form['filters']['filters-container']['area-container']['area'] = [
      '#title' => 'Area',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'core' => $this->t('Core'),
        'contrib' => $this->t('Contrib'),
        'custom' => $this->t('Custom'),
      ],
      '#default_value' => $area_dropdown,
      '#ajax' => [
        'callback' => [$this, 'getModulesCallback'],
        'event' => 'change',
        'method' => 'replace',
        'wrapper' => 'phpstan-test-modules-container',
        'progress' => ['type' => 'none'],
      ],
    ];

    $moduleDropdown = $form_state->hasValue('module') ? $form_state->getValue('module') : '';
    $module_dropdown = !empty($session_filters['module']) ? $session_filters['module'] : $moduleDropdown;

    $form['filters']['filters-container']['module-container'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="area"]' => [
            [
              '!value' => '',
            ],
          ],
        ],
      ],
    ];
    $form['filters']['filters-container']['module-container']['module'] = [
      '#title' => 'Module',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => $this->phpstanTestsResourceService->getResource($area_dropdown),
      '#default_value' => $module_dropdown,
      '#prefix' => '<div id="phpstan-test-modules-container">',
      '#suffix' => '</div>',
      '#states' => [
        'visible' => [
          ':input[name="area"]' => [
            [
              '!value' => '',
            ],
          ],
        ],
      ],
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * Selects just the second dropdown to be returned for re-rendering.
   *
   * @return array
   *   The renderable element.
   */
  public function getModulesCallback($form, $form_state) {
    return $form['filters']['filters-container']['module-container'];
  }

  /**
   * Creates a log entry.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   * @param string $module
   *   The module name.
   * @param string $lineNumber
   *   The line number where the eroor is.
   * @param string $fileChecked
   *   The file with the error.
   * @param string $ignore
   *   If you could ignore this error.
   * @param string $errorReport
   *   The error reported.
   *
   * @return bool
   *   True or false depending on if insert succeeds.
   */
  public function createLog($area, $module, $lineNumber, $fileChecked, $ignore, $errorReport) {
    return $this->connection->insert('phpstan_test_item')
      ->fields([
        'area' => $area,
        'module' => $module,
        'line_number' => $lineNumber,
        'file_checked' => $fileChecked,
        'ignore' => $ignore,
        'error_report' => $errorReport,
        'created' => $this->timeInterface->getRequestTime(),
      ])
      ->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->isValueEmpty('action')) {
      $form_state->setErrorByName('action', $this->t('You must select something to filter by.'));
    }
    if (!in_array($form_state->getValue('action'), ['filter', 'test'])) {
      $form_state->setErrorByName('action', $this->t('Invalid option.'));
    }
    if ($form_state->isValueEmpty('area')) {
      $form_state->setErrorByName('area', $this->t('You must select something to filter by.'));
    }
    if (!in_array($form_state->getValue('area'), $this->areas)) {
      $form_state->setErrorByName('area', $this->t('Invalid option.'));
    }
    if ($form_state->isValueEmpty('module')) {
      $form_state->setErrorByName('module', $this->t('You must select something to filter by.'));
    }
    if (!preg_match('/[A-za-z\s]+/', $form_state->getValue('module'))) {
      $form_state->setErrorByName('module', $this->t('Invalid option.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('phpstan_tests_overview_filter', []);

    if ($form_state->getValue('action') == 'test') {
      $reportArray = $this->phpstanTestsResourceService->getPhpStanReport($form_state->getValue('area'), $form_state->getValue('module'));
      if (count($reportArray) > 0) {
        $ifDbError = FALSE;
        $count = 0;
        foreach ($reportArray as $line) {
          $result = $this->createLog(
            $form_state->getValue('area'),
            $form_state->getValue('module'),
            $line['line'],
            $line['file'],
            $line['ignore'],
            $line['error'],
          );
          if (!$result) {
            $ifDbError = TRUE;
          }
          else {
            $count++;
          }
        }
        if ($ifDbError) {
          $this->messenger->addStatus('Phpstan test could not not been recorded. Please be sure the correct composer packages are loaded.');
        }
        else {
          $this->messenger->addStatus($count . ' Phpstan tests has been recorded.');
        }
      }
      else {
        $this->messenger->addStatus('Congratulations! You have no errors.');
      }
    }

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('phpstan_tests_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('phpstan_tests_overview_filter');
  }

}

==> testsuite-3.0.48-beta1.tar.gz: testsuite/modules/phpstan_tests/src/Form/PhpstanTestsFilterForm.php <==
<?php

namespace Drupal\phpstan_tests\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\phpstan_tests\PhpstanTestsFileResourceService;
use Drupal\phpstan_tests\PhpstanTestsResourceService;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the database logging filter form.
 *
 * @internal
 */
class PhpstanTestsFilterForm extends FormBase {
  use BaseTrait;

  /**
   * The array of filters.
   *
   * @var array
   */
  public $filters = [
    'action',
    'level',
    'area',
    'module',
  ];

  /**
   * The database.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Load the Resource Service.
   *
   * @var \Drupal\phpstan_tests\PhpstanTestsResourceService
   */
  protected $phpstanTestsResourceService;

  /**
   * The time interface.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * Initializer Service.
   *
   * @var \Drupal\phpstan_tests\PhpstanTestsFileResourceService
   */
  protected $phpstanTestsFileResourceService;

  /**
   * PhpUnitTestsForm constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   Load messenger service.
   * @param \Drupal\phpstan_tests\PhpstanTestsResourceService $phpstanTestsResourceService
   *   The load resource service.
   * @param \Drupal\Component\Datetime\TimeInterface $timeInterface
   *   The load resource service.
   * @param \Drupal\phpstan_tests\PhpstanTestsFileResourceService $phpstanTestsFileResourceService
   *   The initializer service that creates configeration files.
   */
  public function __construct(
        Connection $connection,
        MessengerInterface $messenger,
        PhpstanTestsResourceService $phpstanTestsResourceService,
        TimeInterface $timeInterface,
        PhpstanTestsFileResourceService $phpstanTestsFileResourceService
    ) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->phpstanTestsResourceService = $phpstanTestsResourceService;
    $this->timeInterface = $timeInterface;
    $this->phpstanTestsFileResourceService = $phpstanTestsFileResourceService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database'),
          $container->get('messenger'),
          $container->get('phpstan_tests.load_resource.service'),
          $container->get('datetime.time'),
          $container->get('phpstan_tests.file_resource.service')
      );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'phpstan_tests_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('phpstan_tests_overview_filter', []);

    $form['filters'] = [
      '#type' => 'details',
      '#title' => $this->t('Filter log messages'),
      '#open' => TRUE,
      '#attached' => [
        'library' => [
          'phpstan_tests/phpstan_tests.filters',
        ],
      ],
    ];

    $form['filters']['filters-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-tests-filter-form-wrapper',
      ],
    ];

    $actionDropdown = $form_state->hasValue('action') ? $form_state->getValue('action') : '';
    $action_dropdown = !empty($session_filters['action']) ? $session_filters['action'] : $actionDropdown;

    $form['filters']['filters-container']['action-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-test-action-container',
      ],
    ];
    $form['filters']['filters-container']['action-container']['action'] = [
      '#title' => 'Actions',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'filter' => $this->t('Filter'),
        'test' => $this->t('Run Test'),
      ],
      '#default_value' => $action_dropdown,
    ];

    $levelDropdown = $form_state->hasValue('level') ? $form_state->getValue('level') : '';
    $level_dropdown = !empty($session_filters['level']) ? $session_filters['level'] : $levelDropdown;

    $form['filters']['filters-container']['level-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-test-levels-container',
      ],
    ];
    $form['filters']['filters-container']['level-container']['level'] = [
      '#title' => 'Level',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        1 => $this->t('Level 1'),
        2 => $this->t('Level 2'),
        3 => $this->t('Level 3'),
        4 => $this->t('Level 4'),
        5 => $this->t('Level 5'),
        6 => $this->t('Level 6'),
        7 => $this->t('Level 7'),
        8 => $this->t('Level 8'),
        9 => $this->t('Level 9'),
      ],
      '#default_value' => $level_dropdown,
    ];

    $areaDropdown = $form_state->hasValue('area') ? $form_state->getValue('area') : '';
    $area_dropdown = !empty($session_filters['area']) ? $session_filters['area'] : $areaDropdown;

    $form['filters']['filters-container']['area-container'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'phpstan-test-areas-container',
      ],
    ];
    $form['filters']['filters-container']['area-container']['area'] = [
      '#title' => 'Area',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => [
        'core' => $this->t('Core'),
        'contrib' => $this->t('Contrib'),
        'custom' => $this->t('Custom'),
      ],
      '#default_value' => $area_dropdown,
      '#ajax' => [
        'callback' => [$this, 'getModulesCallback'],
        'event' => 'change',
        'method' => 'replace',
        'wrapper' => 'phpstan-test-modules-container',
        'progress' => ['type' => 'none'],
      ],
    ];

    $moduleDropdown = $form_state->hasValue('module') ? $form_state->getValue('module') : '';
    $module_dropdown = !empty($session_filters['module']) ? $session_filters['module'] : $moduleDropdown;

    $form['filters']['filters-container']['module-container'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="area"]' => [
          [
            '!value' => '',
          ],
          ],
        ],
      ],
    ];
    $form['filters']['filters-container']['module-container']['module'] = [
      '#title' => 'Module',
      '#type' => 'select',
      '#multiple' => FALSE,
      '#size' => 8,
      '#options' => $this->phpstanTestsResourceService->getResource($area_dropdown),
      '#default_value' => $module_dropdown,
      '#prefix' => '<div id="phpstan-test-modules-container">',
      '#suffix' => '</div>',
      '#states' => [
        'visible' => [
          ':input[name="area"]' => [
          [
            '!value' => '',
          ],
          ],
        ],
      ],
    ];

    $form['filters']['actions'] = [
      '#type' => 'actions',
      '#attributes' => ['class' => ['container-inline']],
    ];
    $form['filters']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    if (!empty($session_filters)) {
      $form['filters']['actions']['reset'] = [
        '#type' => 'submit',
        '#value' => $this->t('Reset'),
        '#limit_validation_errors' => [],
        '#submit' => ['::resetForm'],
      ];
    }
    return $form;
  }

  /**
   * Selects just the second dropdown to be returned for re-rendering.
   *
   * @param array $form
   *   — An associative array containing the structure of the form.
   *
   * @return array
   *   The renderable element.
   */
  public function getModulesCallback($form) {
    return $form['filters']['filters-container']['module-container'];
  }

  /**
   * Creates a log entry.
   *
   * @param string $level
   *   The level selected. 1 - 9.
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   * @param string $module
   *   The module name.
   * @param string $lineNumber
   *   The line number where the eroor is.
   * @param string $fileChecked
   *   The file with the error.
   * @param string $ignore
   *   If you could ignore this error.
   * @param string $errorReport
   *   The error reported.
   *
   * @return bool
   *   True or false depending on if insert succeeds.
   */
  public function createLog($level, $area, $module, $lineNumber, $fileChecked, $ignore, $errorReport) {
    return $this->connection->insert('phpstan_test_item')
      ->fields(
              [
                'level' => $level,
                'area' => $area,
                'module' => $module,
                'line_number' => $lineNumber,
                'file_checked' => $fileChecked,
                'ignore' => $ignore,
                'error_report' => $errorReport,
                'created' => $this->timeInterface->getRequestTime(),
              ]
          )
      ->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->isValueEmpty('action')) {
      $form_state->setErrorByName('action', $this->t('You must select something to filter by.'));
    }
    if (!in_array($form_state->getValue('action'), ['filter', 'test'])) {
      $form_state->setErrorByName('action', $this->t('Invalid option.'));
    }
    if ($form_state->isValueEmpty('level')) {
      $form_state->setErrorByName('level', $this->t('You must select something to filter by.'));
    }
    if (!in_array($form_state->getValue('level'), [1, 2, 3, 4, 5, 6, 7, 8, 9])) {
      $form_state->setErrorByName('level', $this->t('Invalid option.'));
    }
    if ($form_state->isValueEmpty('area')) {
      $form_state->setErrorByName('area', $this->t('You must select something to filter by.'));
    }
    if (!in_array($form_state->getValue('area'), $this->areas)) {
      $form_state->setErrorByName('area', $this->t('Invalid option.'));
    }
    if ($form_state->isValueEmpty('module')) {
      $form_state->setErrorByName('module', $this->t('You must select something to filter by.'));
    }
    if (!preg_match('/[A-za-z\s]+/', $form_state->getValue('module'))) {
      $form_state->setErrorByName('module', $this->t('Invalid option.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $session_filters = $this->getRequest()->getSession()->get('phpstan_tests_overview_filter', []);

    if ($form_state->getValue('action') == 'test') {
      if ($form_state->getValue('area') == 'core') {
        $phpstanData['phpstan_path'] = DRUPAL_ROOT . DIRECTORY_SEPARATOR . 'core' . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . $form_state->getValue('module');
      }
      else {
        $phpstanData['phpstan_path'] = DRUPAL_ROOT . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . $form_state->getValue('area') . DIRECTORY_SEPARATOR . $form_state->getValue('module');
      }
      $phpstanData['phpstan_level'] = $form_state->getValue('level');
      if ($this->phpstanTestsFileResourceService->ifRootIsWritable()) {
        $this->phpstanTestsFileResourceService->buildPhpStanNeon($phpstanData);
      }
      else {
        $this->messenger->addStatus('The phpstan.neon file was unable to be created. This is most likely due to permissions on the root folder.');
      }

      $reportArray = $this->phpstanTestsResourceService->getPhpStanReport($form_state->getValue('area'), $form_state->getValue('module'));
      if (count($reportArray) > 0) {
        $ifDbError = FALSE;
        $count = 0;
        foreach ($reportArray as $line) {
          $result = $this->createLog(
                $form_state->getValue('level'),
                $form_state->getValue('area'),
                $form_state->getValue('module'),
                $line['line'],
                $line['file'],
                $line['ignore'],
                $line['error'],
            );
          if (!$result) {
            $ifDbError = TRUE;
          }
          else {
            $count++;
          }
        }
        if ($ifDbError) {
          $this->messenger->addStatus('Phpstan test could not not been recorded. Please be sure the correct composer packages are loaded.');
        }
        else {
          $this->messenger->addStatus($count . ' Phpstan tests has been recorded.');
        }
      }
      else {
        $this->messenger->addStatus('Congratulations! You have no errors.');
      }
    }

    foreach ($this->filters as $name) {
      if ($form_state->hasValue($name)) {
        $session_filters[$name] = $form_state->getValue($name);
      }
    }
    $this->getRequest()->getSession()->set('phpstan_tests_overview_filter', $session_filters);
  }

  /**
   * Resets the filter form.
   */
  public function resetForm() {
    $this->getRequest()->getSession()->remove('phpstan_tests_overview_filter');
  }

}
